==> paraview-v3.2.2.zip: paraview-v3.2.2/Qt/Core/pqPlotViewLineChart.h <==
/*=========================================================================

   Program: ParaView
   Module:    pqPlotViewLineChart.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.1. 

   See License_v1.1.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

/// \file pqPlotViewLineChart.h
/// \date 7/13/2007

#ifndef _pqPlotViewLineChart_h
#define _pqPlotViewLineChart_h


#include "pqCoreExport.h"
#include <QObject>

class pqChartArea;
class pqChartLegendModel;
class pqLineChartRepresentation;
class pqPlotViewLineChartInternal;
class vtkObject;


class PQCORE_EXPORT pqPlotViewLineChart : public QObject
{
  Q_OBJECT

public:
  /// Used to index the chart and model arrays.
  enum ChartLocation
  {
    BottomLeft = 0, ///< Index of the bottom-left chart.
    BottomRight,    ///< Index of the bottom-right chart.
    TopLeft,        ///< Index of the top-left chart.
    TopRight        ///< Index of the top-right chart.
  };

public:
  pqPlotViewLineChart(QObject *parent=0);
  virtual ~pqPlotViewLineChart();

  void initialize(pqChartArea *chartArea, pqChartLegendModel *legend);

  void update(bool force=false);

  void addRepresentation(pqLineChartRepresentation *lineChart);
  void removeRepresentation(pqLineChartRepresentation *lineChart);
  void removeAllRepresentations();

public:
  pqPlotViewLineChartInternal *Internal;
};

#endif

==> paraview-v3.4.0.zip: paraview-v3.4.0/Qt/Core/pqPlotViewLineChart.h <==
/*=========================================================================

   Program: ParaView
   Module:    pqPlotViewLineChart.h

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2. 

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

/// \file pqPlotViewLineChart.h
/// \date 7/13/2007

#ifndef _pqPlotViewLineChart_h
#define _pqPlotViewLineChart_h


#include "pqCoreExport.h"
#include <QObject>
#include "pqLineChartSeries.h"

class pqChartArea;
class pqChartLegendModel;
class pqLineChartRepresentation;
class pqPlotViewLineChartInternal;
class vtkObject;


class PQCORE_EXPORT pqPlotViewLineChart : public QObject
{
  Q_OBJECT

public:
  /// Used to index the chart and model arrays.
  enum ChartLocation
  {
    BottomLeft = 0, ///< Index of the bottom-left chart.
    BottomRight,    ///< Index of the bottom-right chart.
    TopLeft,        ///< Index of the top-left chart.
    TopRight        ///< Index of the top-right chart.
  };

public:
  pqPlotViewLineChart(QObject *parent=0);
  virtual ~pqPlotViewLineChart();

  void initialize(pqChartArea *chartArea, pqChartLegendModel *legend);

  void update(bool force=false);

  void addRepresentation(pqLineChartRepresentation *lineChart);
  void removeRepresentation(pqLineChartRepresentation *lineChart);
  void removeAllRepresentations();

  void setSequenceType(pqLineChartSeries::SequenceType type);
  pqLineChartSeries::SequenceType getSequenceType() const;

public:
  pqPlotViewLineChartInternal *Internal;
};

#endif
